@@ -7,7 +7,7 @@ build_time_vars = {'ABIFLAGS': '',
  'ALIGNOF_SIZE_T': 4,
  'ALT_SOABI': 0,
  'ANDROID_API_LEVEL': 0,
- 'AR': 'hppa1.1-unknown-linux-gnu-ar',
+ 'AR': 'hppa2.0-unknown-linux-gnu-ar',
  'ARFLAGS': 'rcs',
  'BASECFLAGS': '-Wsign-compare',
  'BASECPPFLAGS': '',
@@ -15,13 +15,13 @@ build_time_vars = {'ABIFLAGS': '',
  'BINDIR': '/usr/bin',
  'BINLIBDEST': '/usr/lib/python3.11',
  'BLDLIBRARY': '-L. -lpython3.11',
- 'BLDSHARED': 'hppa1.1-unknown-linux-gnu-gcc -shared',
+ 'BLDSHARED': 'hppa2.0-unknown-linux-gnu-gcc -shared',
  'BOOTSTRAP_HEADERS': '\\',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
- 'BUILD_GNU_TYPE': 'hppa1.1-unknown-linux-gnu',
+ 'BUILD_GNU_TYPE': 'hppa2.0-unknown-linux-gnu',
  'BYTESTR_DEPS': '\\',
- 'CC': 'hppa1.1-unknown-linux-gnu-gcc',
+ 'CC': 'hppa2.0-unknown-linux-gnu-gcc',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-Wsign-compare -DNDEBUG',
  'CFLAGSFORSHARED': '-fPIC',
@@ -30,7 +30,7 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '',
- 'CONFIGURE_CFLAGS_NODIST': '-O2 -pipe -march=1.1 -fwrapv -std=c11 -Wextra '
+ 'CONFIGURE_CFLAGS_NODIST': '-O2 -pipe -march=2.0 -fwrapv -std=c11 -Wextra '
                             '-Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Wstrict-prototypes '
@@ -40,38 +40,38 @@ build_time_vars = {'ABIFLAGS': '',
  'CONFIGURE_LDFLAGS': '',
  'CONFIGURE_LDFLAGS_NODIST': '-Wl,-O1 -Wl,--as-needed',
  'CONFIGURE_LDFLAGS_NOLTO': '',
- 'CONFIG_ARGS': "'--prefix=/usr' '--build=hppa1.1-unknown-linux-gnu' "
-                "'--host=hppa1.1-unknown-linux-gnu' '--mandir=/usr/share/man' "
+ 'CONFIG_ARGS': "'--prefix=/usr' '--build=hppa2.0-unknown-linux-gnu' "
+                "'--host=hppa2.0-unknown-linux-gnu' '--mandir=/usr/share/man' "
                 "'--infodir=/usr/share/info' '--datadir=/usr/share' "
                 "'--sysconfdir=/etc' '--localstatedir=/var/lib' "
-                "'--docdir=/usr/share/doc/python-3.11.6' "
-                "'--htmldir=/usr/share/doc/python-3.11.6/html' "
+                "'--docdir=/usr/share/doc/python-3.11.7' "
+                "'--htmldir=/usr/share/doc/python-3.11.7/html' "
                 "'--libdir=/usr/lib' 'ac_cv_header_stropts_h=no' "
                 "'--enable-shared' '--without-static-libpython' "
                 "'--enable-ipv6' '--infodir=/usr/share/info' "
                 "'--mandir=/usr/share/man' '--with-computed-gotos' "
                 "'--with-dbmliborder=gdbm' '--with-libc=' "
                 "'--enable-loadable-sqlite-extensions' '--without-ensurepip' "
-                "'--with-system-expat' '--with-system-ffi' "
+                "'--without-lto' '--with-system-expat' '--with-system-ffi' "
                 "'--with-platlibdir=lib' '--with-pkg-config=yes' "
                 "'--with-wheel-pkg-dir=/usr/lib/python/ensurepip' "
-                "'--without-assertions' '--without-lto' "
-                "'--disable-optimizations' '--with-readline=readline' "
-                "'--without-valgrind' 'build_alias=hppa1.1-unknown-linux-gnu' "
-                "'host_alias=hppa1.1-unknown-linux-gnu' "
-                "'PKG_CONFIG=hppa1.1-unknown-linux-gnu-pkg-config' 'CFLAGS=' "
+                "'--without-assertions' '--disable-optimizations' "
+                "'--with-readline=readline' '--without-valgrind' "
+                "'build_alias=hppa2.0-unknown-linux-gnu' "
+                "'host_alias=hppa2.0-unknown-linux-gnu' "
+                "'PKG_CONFIG=hppa2.0-unknown-linux-gnu-pkg-config' 'CFLAGS=' "
                 "'LDFLAGS=' 'CPPFLAGS= -I/usr/include/ncursesw'",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.11',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/var/tmp/portage/dev-lang/python-3.11.6/work/Python-3.11.6/coverage.info',
+ 'COVERAGE_INFO': '/var/tmp/portage/dev-lang/python-3.11.7/work/Python-3.11.7/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/var/tmp/portage/dev-lang/python-3.11.6/work/Python-3.11.6/lcov-report',
+ 'COVERAGE_REPORT': '/var/tmp/portage/dev-lang/python-3.11.7/work/Python-3.11.7/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.11 LCOV report [commit $(shell '
                             ')]"',
  'CPPFLAGS': '-I. -I./Include -I/usr/include/ncursesw',
- 'CXX': 'hppa1.1-unknown-linux-gnu-g++',
+ 'CXX': 'hppa2.0-unknown-linux-gnu-g++',
  'DECIMAL_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_32=1 -DANSI=1',
  'DECIMAL_LDFLAGS': '-lm Modules/_decimal/libmpdec/libmpdec.a',
  'DEEPFREEZE_C': 'Python/deepfreeze/deepfreeze.c',
@@ -140,7 +140,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_BLUETOOTH_BLUETOOTH_H': 0,
  'HAVE_BLUETOOTH_H': 0,
  'HAVE_BROKEN_MBSTOWCS': 0,
- 'HAVE_BROKEN_NICE': 0,
+ 'HAVE_BROKEN_NICE': 1,
  'HAVE_BROKEN_PIPE_BUF': 0,
  'HAVE_BROKEN_POLL': 0,
  'HAVE_BROKEN_POSIX_SEMAPHORES': 0,
@@ -424,6 +424,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_RENAMEAT': 1,
  'HAVE_RL_APPEND_HISTORY': 1,
  'HAVE_RL_CATCH_SIGNAL': 1,
+ 'HAVE_RL_COMPDISP_FUNC_T': 1,
  'HAVE_RL_COMPLETION_APPEND_CHARACTER': 1,
  'HAVE_RL_COMPLETION_DISPLAY_MATCHES_HOOK': 1,
  'HAVE_RL_COMPLETION_MATCHES': 1,
@@ -605,7 +606,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_ZLIB_H': 0,
  'HAVE__GETPTY': 0,
  'HOSTRUNNER': '',
- 'HOST_GNU_TYPE': 'hppa1.1-unknown-linux-gnu',
+ 'HOST_GNU_TYPE': 'hppa2.0-unknown-linux-gnu',
  'INCLDIRSTOMAKE': '/usr/include /usr/include /usr/include/python3.11 '
                    '/usr/include/python3.11',
  'INCLUDEDIR': '/usr/include',
@@ -618,18 +619,18 @@ build_time_vars = {'ABIFLAGS': '',
  'INSTSONAME': 'libpython3.11.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
- 'LDCXXSHARED': 'hppa1.1-unknown-linux-gnu-g++ -shared',
+ 'LDCXXSHARED': 'hppa2.0-unknown-linux-gnu-g++ -shared',
  'LDFLAGS': '',
  'LDFLAGS_NODIST': '',
  'LDLIBRARY': 'libpython3.11.so',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'hppa1.1-unknown-linux-gnu-gcc -shared',
+ 'LDSHARED': 'hppa2.0-unknown-linux-gnu-gcc -shared',
  'LDVERSION': '3.11',
  'LIBC': '',
  'LIBDEST': '/usr/lib/python3.11',
  'LIBDIR': '/usr/lib',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
- 'LIBEXPAT_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -pipe -march=1.1 -fwrapv '
+ 'LIBEXPAT_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -pipe -march=2.0 -fwrapv '
                     '-std=c11 -Wextra -Wno-unused-parameter '
                     '-Wno-missing-field-initializers -Wstrict-prototypes '
                     '-Werror=implicit-function-declaration '
@@ -641,7 +642,7 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBM': '-lm',
  'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
  'LIBMPDEC_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_32=1 -DANSI=1 '
-                    '-Wsign-compare -DNDEBUG -O2 -pipe -march=1.1 -fwrapv '
+                    '-Wsign-compare -DNDEBUG -O2 -pipe -march=2.0 -fwrapv '
                     '-std=c11 -Wextra -Wno-unused-parameter '
                     '-Wno-missing-field-initializers -Wstrict-prototypes '
                     '-Werror=implicit-function-declaration '
@@ -660,7 +661,7 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
  'LIBS': '-ldl',
  'LIBSUBDIRS': 'asyncio \\',
- 'LINKCC': 'hppa1.1-unknown-linux-gnu-gcc',
+ 'LINKCC': 'hppa2.0-unknown-linux-gnu-gcc',
  'LINKFORSHARED': '-Xlinker -export-dynamic',
  'LINK_PYTHON_DEPS': 'libpython3.11.so libpython3.so',
  'LINK_PYTHON_OBJS': '-L. -lpython3.11',
@@ -675,7 +676,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MACHDEP_OBJS': '',
  'MACHDESTLIB': '/usr/lib/python3.11',
  'MACOSX_DEPLOYMENT_TARGET': '',
- 'MAINCC': 'hppa1.1-unknown-linux-gnu-gcc',
+ 'MAINCC': 'hppa2.0-unknown-linux-gnu-gcc',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 1,
  'MAKESETUP': './Modules/makesetup',
@@ -937,7 +938,7 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
- 'PY_BUILTIN_MODULE_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -pipe -march=1.1 '
+ 'PY_BUILTIN_MODULE_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -pipe -march=2.0 '
                              '-fwrapv -std=c11 -Wextra -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Wstrict-prototypes '
@@ -946,13 +947,13 @@ build_time_vars = {'ABIFLAGS': '',
                              '-I./Include -I/usr/include/ncursesw -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wsign-compare -DNDEBUG',
- 'PY_CFLAGS_NODIST': '-O2 -pipe -march=1.1 -fwrapv -std=c11 -Wextra '
+ 'PY_CFLAGS_NODIST': '-O2 -pipe -march=2.0 -fwrapv -std=c11 -Wextra '
                      '-Wno-unused-parameter -Wno-missing-field-initializers '
                      '-Wstrict-prototypes '
                      '-Werror=implicit-function-declaration '
                      '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
- 'PY_CORE_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -pipe -march=1.1 -fwrapv '
+ 'PY_CORE_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -pipe -march=2.0 -fwrapv '
                    '-std=c11 -Wextra -Wno-unused-parameter '
                    '-Wno-missing-field-initializers -Wstrict-prototypes '
                    '-Werror=implicit-function-declaration -fvisibility=hidden  '
@@ -969,7 +970,7 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_SQLITE_HAVE_SERIALIZE': 1,
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
- 'PY_STDMODULE_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -pipe -march=1.1 -fwrapv '
+ 'PY_STDMODULE_CFLAGS': '-Wsign-compare -DNDEBUG -O2 -pipe -march=2.0 -fwrapv '
                         '-std=c11 -Wextra -Wno-unused-parameter '
                         '-Wno-missing-field-initializers -Wstrict-prototypes '
                         '-Werror=implicit-function-declaration '
@@ -980,12 +981,13 @@ build_time_vars = {'ABIFLAGS': '',
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
  'Py_STATS': 0,
+ 'Py_SUNOS_VERSION': 0,
  'Py_TRACE_REFS': 0,
  'QUICKTESTOPTS': '-x test_subprocess test_io test_lib2to3 \\',
- 'READELF': 'hppa1.1-unknown-linux-gnu-readelf',
+ 'READELF': 'hppa2.0-unknown-linux-gnu-readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.6/work/Python-3.11.6',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.7/work/Python-3.11.7',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SHELL': '/bin/sh',
@@ -1029,10 +1031,10 @@ build_time_vars = {'ABIFLAGS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.6/work/Python-3.11.6 '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.7/work/Python-3.11.7 '
                './python -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.6/work/Python-3.11.6 '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.7/work/Python-3.11.7 '
                './python -E ./Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'ctypes/test \\',
  'TESTTIMEOUT': 1200,
@@ -1063,8 +1065,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/var/tmp/portage/dev-lang/python-3.11.6/work/Python-3.11.6',
- 'abs_srcdir': '/var/tmp/portage/dev-lang/python-3.11.6/work/Python-3.11.6',
+ 'abs_builddir': '/var/tmp/portage/dev-lang/python-3.11.7/work/Python-3.11.7',
+ 'abs_srcdir': '/var/tmp/portage/dev-lang/python-3.11.7/work/Python-3.11.7',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
