@@ -7,41 +7,45 @@ build_time_vars = {'ABIFLAGS': '',
  'ALIGNOF_SIZE_T': 8,
  'ALT_SOABI': 0,
  'ANDROID_API_LEVEL': 0,
- 'AR': 'x86_64-pc-linux-gnu-ar',
+ 'AR': '/usr/lib/llvm/17/bin/llvm-ar',
  'ARFLAGS': 'rcs',
- 'BASECFLAGS': '-Wsign-compare',
+ 'BASECFLAGS': '-Wsign-compare -Wunreachable-code',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
  'BINDIR': '/usr/bin',
  'BINLIBDEST': '/usr/lib/python3.11',
  'BLDLIBRARY': '-L. -lpython3.11',
- 'BLDSHARED': 'x86_64-pc-linux-gnu-gcc -shared',
+ 'BLDSHARED': 'clang -shared',
  'BOOTSTRAP_HEADERS': '\\',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
  'BUILD_GNU_TYPE': 'x86_64-pc-linux-gnu',
  'BYTESTR_DEPS': '\\',
- 'CC': 'x86_64-pc-linux-gnu-gcc',
+ 'CC': 'clang',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-Wsign-compare -DNDEBUG',
+ 'CFLAGS': '-Wsign-compare -Wunreachable-code -DNDEBUG',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
- 'CFLAGS_NODIST': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
  'CONFIGURE_CFLAGS': '',
- 'CONFIGURE_CFLAGS_NODIST': '-O3 -pipe -march=ivybridge -mtune=skylake '
-                            '-frecord-gcc-switches -fdiagnostics-color=never '
-                            '-fwrapv -std=c11 -Wextra -Wno-unused-parameter '
+ 'CONFIGURE_CFLAGS_NODIST': '-O3 -pipe -march=znver2 -mtune=znver3 '
+                            '-fpermissive -frecord-gcc-switches '
+                            '-fdiagnostics-color=never '
+                            '-Wno-error=implicit-function-declaration '
+                            '-flto=thin -Wno-cflagsver0010 -fwrapv -flto -g '
+                            '-std=c11 -Wextra -Wno-unused-parameter '
                             '-Wno-missing-field-initializers '
                             '-Wstrict-prototypes '
                             '-Werror=implicit-function-declaration '
                             '-fvisibility=hidden',
  'CONFIGURE_CPPFLAGS': '-I/usr/include/ncursesw',
  'CONFIGURE_LDFLAGS': '',
- 'CONFIGURE_LDFLAGS_NODIST': '-Wl,-O1 -Wl,--as-needed '
-                             '-Wl,-z,pack-relative-relocs',
- 'CONFIGURE_LDFLAGS_NOLTO': '',
+ 'CONFIGURE_LDFLAGS_NODIST': '-v -Wl,-O1 -Wl,--as-needed -Wl,--as-needed '
+                             '-Wl,-O2 -Wl,--as-needed '
+                             '-Wl,-z,pack-relative-relocs -Wl,-z,relro '
+                             '-Wl,-z,now -flto -g',
+ 'CONFIGURE_LDFLAGS_NOLTO': '-flto=thin',
  'CONFIG_ARGS': "'--prefix=/usr' '--build=x86_64-pc-linux-gnu' "
                 "'--host=x86_64-pc-linux-gnu' '--mandir=/usr/share/man' "
                 "'--infodir=/usr/share/info' '--datadir=/usr/share' "
@@ -52,17 +56,22 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--enable-shared' '--without-static-libpython' "
                 "'--enable-ipv6' '--infodir=/usr/share/info' "
                 "'--mandir=/usr/share/man' '--with-computed-gotos' "
-                "'--with-dbmliborder=gdbm' '--with-libc=' "
+                "'--with-dbmliborder=' '--with-libc=' "
                 "'--enable-loadable-sqlite-extensions' '--without-ensurepip' "
                 "'--without-lto' '--with-system-expat' '--with-system-ffi' "
                 "'--with-platlibdir=lib' '--with-pkg-config=yes' "
                 "'--with-wheel-pkg-dir=/usr/lib/python/ensurepip' "
-                "'--without-assertions' '--disable-optimizations' "
-                "'--with-readline=readline' '--without-valgrind' "
+                "'--without-assertions' '--enable-optimizations' "
+                "'--with-readline=readline' '--without-valgrind' '--with-lto' "
                 "'build_alias=x86_64-pc-linux-gnu' "
                 "'host_alias=x86_64-pc-linux-gnu' "
-                "'PKG_CONFIG=x86_64-pc-linux-gnu-pkg-config' 'CFLAGS=' "
-                "'LDFLAGS=' 'CPPFLAGS= -I/usr/include/ncursesw'",
+                "'PKG_CONFIG=x86_64-pc-linux-gnu-pkg-config' 'CC=clang' "
+                "'CFLAGS=' 'LDFLAGS=' 'CPPFLAGS= -I/usr/include/ncursesw' "
+                "'CPP=clang-cpp' 'PROFILE_TASK=-m test -j24 --pgo-extended "
+                '-u-network --timeout 1200 -x test_gdb -x test_dtrace -x '
+                'test_asyncio -x test_httpservers -x test_logging -x '
+                'test_multiprocessing_fork -x test_socket -x test_xmlrpc -x '
+                "test_tools'",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.11',
  'COREPYTHONPATH': '',
@@ -73,7 +82,7 @@ build_time_vars = {'ABIFLAGS': '',
                             '--title "CPython 3.11 LCOV report [commit $(shell '
                             ')]"',
  'CPPFLAGS': '-I. -I./Include -I/usr/include/ncursesw',
- 'CXX': 'x86_64-pc-linux-gnu-g++',
+ 'CXX': 'clang++',
  'DECIMAL_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_64=1 -DANSI=1 '
                    '-DHAVE_UINT128_T=1',
  'DECIMAL_LDFLAGS': '-lm Modules/_decimal/libmpdec/libmpdec.a',
@@ -253,7 +262,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_GCC_UINT128_T': 1,
  'HAVE_GDBM_DASH_NDBM_H': 0,
  'HAVE_GDBM_H': 1,
- 'HAVE_GDBM_NDBM_H': 1,
+ 'HAVE_GDBM_NDBM_H': 0,
  'HAVE_GETADDRINFO': 1,
  'HAVE_GETC_UNLOCKED': 1,
  'HAVE_GETEGID': 1,
@@ -326,7 +335,7 @@ build_time_vars = {'ABIFLAGS': '',
  'HAVE_LIBDB': 0,
  'HAVE_LIBDL': 1,
  'HAVE_LIBDLD': 0,
- 'HAVE_LIBGDBM_COMPAT': 1,
+ 'HAVE_LIBGDBM_COMPAT': 0,
  'HAVE_LIBIEEE': 0,
  'HAVE_LIBINTL_H': 1,
  'HAVE_LIBNDBM': 0,
@@ -614,36 +623,37 @@ build_time_vars = {'ABIFLAGS': '',
                    '/usr/include/python3.11',
  'INCLUDEDIR': '/usr/include',
  'INCLUDEPY': '/usr/include/python3.11',
- 'INSTALL': '/var/tmp/portage/._portage_reinstall_.ah3bheib/bin/ebuild-helpers/xattr/install '
-            '-c',
- 'INSTALL_DATA': '/var/tmp/portage/._portage_reinstall_.ah3bheib/bin/ebuild-helpers/xattr/install '
-                 '-c -m 644',
- 'INSTALL_PROGRAM': '/var/tmp/portage/._portage_reinstall_.ah3bheib/bin/ebuild-helpers/xattr/install '
+ 'INSTALL': '/usr/lib/portage/python3.11/ebuild-helpers/xattr/install -c',
+ 'INSTALL_DATA': '/usr/lib/portage/python3.11/ebuild-helpers/xattr/install -c '
+                 '-m 644',
+ 'INSTALL_PROGRAM': '/usr/lib/portage/python3.11/ebuild-helpers/xattr/install '
                     '-c',
- 'INSTALL_SCRIPT': '/var/tmp/portage/._portage_reinstall_.ah3bheib/bin/ebuild-helpers/xattr/install '
+ 'INSTALL_SCRIPT': '/usr/lib/portage/python3.11/ebuild-helpers/xattr/install '
                    '-c',
- 'INSTALL_SHARED': '/var/tmp/portage/._portage_reinstall_.ah3bheib/bin/ebuild-helpers/xattr/install '
+ 'INSTALL_SHARED': '/usr/lib/portage/python3.11/ebuild-helpers/xattr/install '
                    '-c -m 755',
  'INSTSONAME': 'libpython3.11.so.1.0',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
- 'LDCXXSHARED': 'x86_64-pc-linux-gnu-g++ -shared',
+ 'LDCXXSHARED': 'clang++ -shared',
  'LDFLAGS': '',
- 'LDFLAGS_NODIST': '',
  'LDLIBRARY': 'libpython3.11.so',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'x86_64-pc-linux-gnu-gcc -shared',
+ 'LDSHARED': 'clang -shared',
  'LDVERSION': '3.11',
  'LIBC': '',
  'LIBDEST': '/usr/lib/python3.11',
  'LIBDIR': '/usr/lib64',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
- 'LIBEXPAT_CFLAGS': '-Wsign-compare -DNDEBUG -O3 -pipe -march=ivybridge '
-                    '-mtune=skylake -frecord-gcc-switches '
-                    '-fdiagnostics-color=never -fwrapv -std=c11 -Wextra '
+ 'LIBEXPAT_CFLAGS': '-Wsign-compare -Wunreachable-code -DNDEBUG -O3 -pipe '
+                    '-march=znver2 -mtune=znver3 -fpermissive '
+                    '-frecord-gcc-switches -fdiagnostics-color=never '
+                    '-Wno-error=implicit-function-declaration -flto=thin '
+                    '-Wno-cflagsver0010 -fwrapv -flto -g -std=c11 -Wextra '
                     '-Wno-unused-parameter -Wno-missing-field-initializers '
                     '-Wstrict-prototypes -Werror=implicit-function-declaration '
-                    '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
+                    '-fvisibility=hidden -fprofile-instr-use=code.profclangd '
+                    '-I./Include/internal -I. -I./Include '
                     '-I/usr/include/ncursesw -fPIC -fPIC',
  'LIBEXPAT_HEADERS': '\\',
  'LIBEXPAT_OBJS': '\\',
@@ -651,12 +661,16 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBM': '-lm',
  'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
  'LIBMPDEC_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_64=1 -DANSI=1 '
-                    '-DHAVE_UINT128_T=1 -Wsign-compare -DNDEBUG -O3 -pipe '
-                    '-march=ivybridge -mtune=skylake -frecord-gcc-switches '
-                    '-fdiagnostics-color=never -fwrapv -std=c11 -Wextra '
+                    '-DHAVE_UINT128_T=1 -Wsign-compare -Wunreachable-code '
+                    '-DNDEBUG -O3 -pipe -march=znver2 -mtune=znver3 '
+                    '-fpermissive -frecord-gcc-switches '
+                    '-fdiagnostics-color=never '
+                    '-Wno-error=implicit-function-declaration -flto=thin '
+                    '-Wno-cflagsver0010 -fwrapv -flto -g -std=c11 -Wextra '
                     '-Wno-unused-parameter -Wno-missing-field-initializers '
                     '-Wstrict-prototypes -Werror=implicit-function-declaration '
-                    '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
+                    '-fvisibility=hidden -fprofile-instr-use=code.profclangd '
+                    '-I./Include/internal -I. -I./Include '
                     '-I/usr/include/ncursesw -fPIC -fPIC',
  'LIBMPDEC_HEADERS': '\\',
  'LIBMPDEC_OBJS': '\\',
@@ -671,27 +685,28 @@ build_time_vars = {'ABIFLAGS': '',
  'LIBRARY_OBJS_OMIT_FROZEN': '\\',
  'LIBS': '-ldl',
  'LIBSUBDIRS': 'asyncio \\',
- 'LINKCC': 'x86_64-pc-linux-gnu-gcc',
+ 'LINKCC': 'clang',
  'LINKFORSHARED': '-Xlinker -export-dynamic',
  'LINK_PYTHON_DEPS': 'libpython3.11.so libpython3.so',
  'LINK_PYTHON_OBJS': '-L. -lpython3.11',
  'LIPO_32BIT_FLAGS': '',
  'LIPO_INTEL64_FLAGS': '',
  'LLVM_PROF_ERR': 'no',
- 'LLVM_PROF_FILE': '',
- 'LLVM_PROF_MERGER': 'true',
+ 'LLVM_PROF_FILE': 'LLVM_PROFILE_FILE="code-%p.profclangr"',
+ 'LLVM_PROF_MERGER': '/usr/lib/llvm/17/bin/llvm-profdata merge '
+                     '-output=code.profclangd *.profclangr',
  'LN': 'ln',
  'LOCALMODLIBS': '',
  'MACHDEP': 'linux',
  'MACHDEP_OBJS': '',
  'MACHDESTLIB': '/usr/lib/python3.11',
  'MACOSX_DEPLOYMENT_TARGET': '',
- 'MAINCC': 'x86_64-pc-linux-gnu-gcc',
+ 'MAINCC': 'clang',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 1,
  'MAKESETUP': './Modules/makesetup',
  'MANDIR': '/usr/share/man',
- 'MKDIR_P': '/usr/bin/mkdir -p',
+ 'MKDIR_P': '/bin/mkdir -p',
  'MODBUILT_NAMES': 'atexit  faulthandler  posix  _signal  _tracemalloc  '
                    '_codecs  _collections  errno  _io  itertools  _sre  '
                    '_thread  time  _weakref  _abc  _functools  _locale  '
@@ -806,7 +821,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__CURSES_STATE': 'yes',
  'MODULE__DATETIME_LDFLAGS': '-lm',
  'MODULE__DATETIME_STATE': 'yes',
- 'MODULE__DBM_STATE': 'yes',
+ 'MODULE__DBM_STATE': 'disabled',
  'MODULE__DECIMAL_CFLAGS': '-I./Modules/_decimal/libmpdec -DCONFIG_64=1 '
                            '-DANSI=1 -DHAVE_UINT128_T=1',
  'MODULE__DECIMAL_DEPS': './Modules/_decimal/docstrings.h \\ '
@@ -817,9 +832,7 @@ build_time_vars = {'ABIFLAGS': '',
  'MODULE__ELEMENTTREE_DEPS': './Modules/pyexpat.c',
  'MODULE__ELEMENTTREE_STATE': 'yes',
  'MODULE__FUNCTOOLS_LDFLAGS': '',
- 'MODULE__GDBM_CFLAGS': '',
- 'MODULE__GDBM_LDFLAGS': '-lgdbm',
- 'MODULE__GDBM_STATE': 'yes',
+ 'MODULE__GDBM_STATE': 'disabled',
  'MODULE__HASHLIB_CFLAGS': '',
  'MODULE__HASHLIB_DEPS': './Modules/hashlib.h',
  'MODULE__HASHLIB_LDFLAGS': '-lcrypto',
@@ -924,12 +937,15 @@ build_time_vars = {'ABIFLAGS': '',
  'PARSER_OBJS': '\\ \\ Parser/myreadline.o Parser/tokenizer.o',
  'PEGEN_HEADERS': '\\',
  'PEGEN_OBJS': '\\',
- 'PGO_PROF_GEN_FLAG': '-fprofile-generate',
- 'PGO_PROF_USE_FLAG': '-fprofile-use -fprofile-correction',
+ 'PGO_PROF_GEN_FLAG': '-fprofile-instr-generate',
+ 'PGO_PROF_USE_FLAG': '-fprofile-instr-use=code.profclangd',
  'PLATLIBDIR': 'lib',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
- 'PROFILE_TASK': '-m test --pgo --timeout=1200',
+ 'PROFILE_TASK': '-m test -j24 --pgo-extended -u-network --timeout 1200 -x '
+                 'test_gdb -x test_dtrace -x test_asyncio -x test_httpservers '
+                 '-x test_logging -x test_multiprocessing_fork -x test_socket '
+                 '-x test_xmlrpc -x test_tools',
  'PTHREAD_KEY_T_IS_COMPATIBLE_WITH_INT': 1,
  'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
  'PURIFY': '',
@@ -948,51 +964,69 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha256,sha512,sha3,blake2"',
- 'PY_BUILTIN_MODULE_CFLAGS': '-Wsign-compare -DNDEBUG -O3 -pipe '
-                             '-march=ivybridge -mtune=skylake '
+ 'PY_BUILTIN_MODULE_CFLAGS': '-Wsign-compare -Wunreachable-code -DNDEBUG -O3 '
+                             '-pipe -march=znver2 -mtune=znver3 -fpermissive '
                              '-frecord-gcc-switches -fdiagnostics-color=never '
-                             '-fwrapv -std=c11 -Wextra -Wno-unused-parameter '
+                             '-Wno-error=implicit-function-declaration '
+                             '-flto=thin -Wno-cflagsver0010 -fwrapv -flto -g '
+                             '-std=c11 -Wextra -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Wstrict-prototypes '
                              '-Werror=implicit-function-declaration '
-                             '-fvisibility=hidden  -I./Include/internal -I. '
-                             '-I./Include -I/usr/include/ncursesw -fPIC '
+                             '-fvisibility=hidden '
+                             '-fprofile-instr-use=code.profclangd '
+                             '-I./Include/internal -I. -I./Include '
+                             '-I/usr/include/ncursesw -fPIC '
                              '-DPy_BUILD_CORE_BUILTIN',
- 'PY_CFLAGS': '-Wsign-compare -DNDEBUG',
- 'PY_CFLAGS_NODIST': '-O3 -pipe -march=ivybridge -mtune=skylake '
-                     '-frecord-gcc-switches -fdiagnostics-color=never -fwrapv '
-                     '-std=c11 -Wextra -Wno-unused-parameter '
-                     '-Wno-missing-field-initializers -Wstrict-prototypes '
+ 'PY_CFLAGS': '-Wsign-compare -Wunreachable-code -DNDEBUG',
+ 'PY_CFLAGS_NODIST': '-O3 -pipe -march=znver2 -mtune=znver3 -fpermissive '
+                     '-frecord-gcc-switches -fdiagnostics-color=never '
+                     '-Wno-error=implicit-function-declaration -flto=thin '
+                     '-Wno-cflagsver0010 -fwrapv -flto -g -std=c11 -Wextra '
+                     '-Wno-unused-parameter -Wno-missing-field-initializers '
+                     '-Wstrict-prototypes '
                      '-Werror=implicit-function-declaration '
-                     '-fvisibility=hidden  -I./Include/internal',
+                     '-fvisibility=hidden -fprofile-instr-use=code.profclangd '
+                     '-I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
- 'PY_CORE_CFLAGS': '-Wsign-compare -DNDEBUG -O3 -pipe -march=ivybridge '
-                   '-mtune=skylake -frecord-gcc-switches '
-                   '-fdiagnostics-color=never -fwrapv -std=c11 -Wextra '
+ 'PY_CORE_CFLAGS': '-Wsign-compare -Wunreachable-code -DNDEBUG -O3 -pipe '
+                   '-march=znver2 -mtune=znver3 -fpermissive '
+                   '-frecord-gcc-switches -fdiagnostics-color=never '
+                   '-Wno-error=implicit-function-declaration -flto=thin '
+                   '-Wno-cflagsver0010 -fwrapv -flto -g -std=c11 -Wextra '
                    '-Wno-unused-parameter -Wno-missing-field-initializers '
                    '-Wstrict-prototypes -Werror=implicit-function-declaration '
-                   '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
+                   '-fvisibility=hidden -fprofile-instr-use=code.profclangd '
+                   '-I./Include/internal -I. -I./Include '
                    '-I/usr/include/ncursesw -fPIC -DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '-Wl,-O1 -Wl,--as-needed -Wl,-z,pack-relative-relocs',
+ 'PY_CORE_LDFLAGS': '-v -Wl,-O1 -Wl,--as-needed -Wl,--as-needed -Wl,-O2 '
+                    '-Wl,--as-needed -Wl,-z,pack-relative-relocs -Wl,-z,relro '
+                    '-Wl,-z,now -flto -g',
  'PY_CPPFLAGS': '-I. -I./Include -I/usr/include/ncursesw',
  'PY_ENABLE_SHARED': 1,
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '',
- 'PY_LDFLAGS_NODIST': '-Wl,-O1 -Wl,--as-needed -Wl,-z,pack-relative-relocs',
- 'PY_LDFLAGS_NOLTO': '',
+ 'PY_LDFLAGS_NODIST': '-v -Wl,-O1 -Wl,--as-needed -Wl,--as-needed -Wl,-O2 '
+                      '-Wl,--as-needed -Wl,-z,pack-relative-relocs '
+                      '-Wl,-z,relro -Wl,-z,now -flto -g',
+ 'PY_LDFLAGS_NOLTO': '-flto=thin',
  'PY_SQLITE_ENABLE_LOAD_EXTENSION': 1,
  'PY_SQLITE_HAVE_SERIALIZE': 1,
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
- 'PY_STDMODULE_CFLAGS': '-Wsign-compare -DNDEBUG -O3 -pipe -march=ivybridge '
-                        '-mtune=skylake -frecord-gcc-switches '
-                        '-fdiagnostics-color=never -fwrapv -std=c11 -Wextra '
+ 'PY_STDMODULE_CFLAGS': '-Wsign-compare -Wunreachable-code -DNDEBUG -O3 -pipe '
+                        '-march=znver2 -mtune=znver3 -fpermissive '
+                        '-frecord-gcc-switches -fdiagnostics-color=never '
+                        '-Wno-error=implicit-function-declaration -flto=thin '
+                        '-Wno-cflagsver0010 -fwrapv -flto -g -std=c11 -Wextra '
                         '-Wno-unused-parameter -Wno-missing-field-initializers '
                         '-Wstrict-prototypes '
                         '-Werror=implicit-function-declaration '
-                        '-fvisibility=hidden  -I./Include/internal -I. '
-                        '-I./Include -I/usr/include/ncursesw -fPIC',
- 'PY_SUPPORT_TIER': 1,
+                        '-fvisibility=hidden '
+                        '-fprofile-instr-use=code.profclangd '
+                        '-I./Include/internal -I. -I./Include '
+                        '-I/usr/include/ncursesw -fPIC',
+ 'PY_SUPPORT_TIER': 2,
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
@@ -1000,7 +1034,7 @@ build_time_vars = {'ABIFLAGS': '',
  'Py_SUNOS_VERSION': 0,
  'Py_TRACE_REFS': 0,
  'QUICKTESTOPTS': '-x test_subprocess test_io test_lib2to3 \\',
- 'READELF': 'x86_64-pc-linux-gnu-readelf',
+ 'READELF': 'llvm-readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
  'RUNSHARED': 'LD_LIBRARY_PATH=/var/tmp/portage/dev-lang/python-3.11.7/work/Python-3.11.7',
